/**
 * Copyright (c) 2010-2012 EBMWebsourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.commons.log;


public abstract class FlowLogData extends LogData {

    private static final long serialVersionUID = -7103476777321787262L;

    /**
     * Name of the contextual property (printed in MONIT trace) storing the
     * trace role (consumer/provider, begin/end) of the step in the flow.
     */
    public static final String FLOW_STEP_TRACE_CODE = "traceCode";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the flow instance identifier. A flow instance is
     * made up of flow steps.
     */
    public static final String FLOW_INSTANCE_ID_PROPERTY_NAME = "flowInstanceId";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the flow step identifier of the flow step in the
     * current flow instance.
     */
    public static final String FLOW_STEP_ID_PROPERTY_NAME = "flowStepId";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the previous step identifier of the curennt
     * step.
     */
    public static final String FLOW_PREVIOUS_STEP_ID_PROPERTY_NAME = "flowPreviousStepId";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the consumed interface name or the invoked
     * provider interface of the current step
     */
    public static final String FLOW_STEP_INTERFACE_NAME_PROPERTY_NAME = "flowStepInterfaceName";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the consumed operation name or the invoked
     * provider operation of the current step
     */
    public static final String FLOW_STEP_OPERATION_NAME_PROPERTY_NAME = "flowStepOperationName";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the consumed service name or the invoked
     * provider service name of the current step.
     */
    public static final String FLOW_STEP_SERVICE_NAME_PROPERTY_NAME = "flowStepServiceName";

    /**
     * Name of the contextual property (printed in MONIT trace) storing the the invoked provider endpoint name of the
     * current step
     */
    public static final String FLOW_STEP_ENDPOINT_NAME_PROPERTY_NAME = "flowStepEndpointName";

    /**
     * Name of the contextual property storing the message exchange
     */
    public static final String FLOW_EXCHANGE_PROPERTY_NAME = "flowStepExchange";

    public FlowLogData(final TraceCode traceCode) {
        super();
        putData(FLOW_STEP_TRACE_CODE, traceCode);
    }
}
